==> v0.13.11.tar.gz: git-next/crates/cli/src/repo/tests/handlers/advance_main.rs <==
//
use super::*;

#[actix::test]
async fn when_repo_config_should_fetch_then_push_then_revalidate() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, mut repo_details) = given::an_open_repository(&fs);

    // config from repo
    #[allow(clippy::unwrap_used)]
    let repo_config = repo_details.repo_config.take().unwrap();
    repo_details.repo_config = Some(repo_config.with_source(RepoConfigSource::Repo));

    let next_commit = given::a_commit_with_message("feat: next".to_string());

    let mut seq = mockall::Sequence::new();
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));
    open_repository
        .expect_push()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|_, _, _, _| Ok(()));
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    addr.send(crate::repo::messages::AdvanceMain::new(next_commit.clone()))
        .await?;
    System::current().stop();

    //then
    tracing::debug!(?log, "");
    log.read().map_err(|e| e.to_string()).map(|l| {
        assert!(l
            .iter()
            .any(|message| message.contains("send: LoadConfigFromRepo")));
    })?;
    Ok(())
}

#[actix::test]
async fn when_app_config_should_fetch_then_push_then_revalidate() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, mut repo_details) = given::an_open_repository(&fs);

    // config from server
    #[allow(clippy::unwrap_used)]
    let repo_config = repo_details.repo_config.take().unwrap();
    repo_details.repo_config = Some(repo_config.with_source(RepoConfigSource::Server));

    let next_commit = given::a_commit_with_message("feat: next".to_string());

    let mut seq = mockall::Sequence::new();
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));
    open_repository
        .expect_push()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|_, _, _, _| Ok(()));
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    addr.send(crate::repo::messages::AdvanceMain::new(next_commit.clone()))
        .await?;
    System::current().stop();

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: ValidateRepo")?;
    Ok(())
}

==> v0.14.1.tar.gz: git-next/crates/cli/src/repo/tests/handlers/advance_main.rs <==
use crate::{repo::messages::AdvanceMain, tell};

//
use super::*;

#[tokio::test]
async fn when_repo_config_should_fetch_then_push_then_revalidate() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, mut repo_details) = given::an_open_repository(&fs);

    // config from repo
    #[allow(clippy::unwrap_used)]
    let repo_config = repo_details.repo_config.take().unwrap();
    repo_details.repo_config = Some(repo_config.with_source(RepoConfigSource::Repo));

    let next_commit = given::a_commit_with_message("feat: next".to_string());

    let mut seq = mockall::Sequence::new();
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));
    open_repository
        .expect_push()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|_, _, _, _| Ok(()));
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    tell!(addr, AdvanceMain::new(next_commit.clone()))?;

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: LoadConfigFromRepo")
        .await?;
    Ok(())
}

#[test_log::test(tokio::test)]
async fn when_app_config_should_fetch_then_push_then_revalidate() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, mut repo_details) = given::an_open_repository(&fs);

    // config from server
    #[allow(clippy::unwrap_used)]
    let repo_config = repo_details.repo_config.take().unwrap();
    repo_details.repo_config = Some(repo_config.with_source(RepoConfigSource::Server));

    let next_commit = given::a_commit_with_message("feat: next".to_string());

    let mut seq = mockall::Sequence::new();
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));
    open_repository
        .expect_push()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|_, _, _, _| Ok(()));
    open_repository
        .expect_fetch()
        .times(1)
        .in_sequence(&mut seq)
        .return_once(|| Ok(()));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    tell!(addr, AdvanceMain::new(next_commit.clone()))?;

    //then
    tracing::debug!(?log, "log");
    log.require_message_containing("send: ValidateRepo").await?;
    Ok(())
}
